var searchData=
[
  ['unit_5fvector',['unit_vector',['../structviennacl_1_1unit__vector.html#acf1edf2697940a7321bdfc8b4e4d459a',1,'viennacl::unit_vector']]],
  ['unknown_5fnorm_5fexception',['unknown_norm_exception',['../classviennacl_1_1unknown__norm__exception.html#a54d00eebcc284ec99fe2ad144f594265',1,'viennacl::unknown_norm_exception']]],
  ['update_5ffloat_5fqr_5fcolumn',['update_float_QR_column',['../namespaceviennacl_1_1linalg_1_1detail.html#a4d6d704d39ec27eb15a604580eb1df5b',1,'viennacl::linalg::detail']]],
  ['update_5ffloat_5fqr_5fcolumn_5fgpu',['update_float_QR_column_gpu',['../namespaceviennacl_1_1linalg_1_1detail.html#a0ce6438b322e096df65112ac6536b0b1',1,'viennacl::linalg::detail']]],
  ['upper_5finplace_5fsolve_5fmatrix',['upper_inplace_solve_matrix',['../namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html#a38989d09acd0c0763276fd94123e9d51',1,'viennacl::linalg::host_based::detail']]],
  ['upper_5finplace_5fsolve_5fvector',['upper_inplace_solve_vector',['../namespaceviennacl_1_1linalg_1_1host__based_1_1detail.html#a96090fa88ab45b1c22ffc5038ce17b2d',1,'viennacl::linalg::host_based::detail']]],
  ['use_5flevel_5fscheduling',['use_level_scheduling',['../classviennacl_1_1linalg_1_1ilu0__tag.html#a80e9be92f4b0b34a8150b6362cb7e969',1,'viennacl::linalg::ilu0_tag::use_level_scheduling() const '],['../classviennacl_1_1linalg_1_1ilu0__tag.html#a95868f0f04b78bf99db86ca3380d8f43',1,'viennacl::linalg::ilu0_tag::use_level_scheduling(bool b)'],['../classviennacl_1_1linalg_1_1ilut__tag.html#ab151e8e08b42253c3de75a8a70047596',1,'viennacl::linalg::ilut_tag::use_level_scheduling() const '],['../classviennacl_1_1linalg_1_1ilut__tag.html#a2042190ce53f7a4bb28356ffd3103a89',1,'viennacl::linalg::ilut_tag::use_level_scheduling(bool b)']]]
];
